package net.wanji.opt.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import net.wanji.common.dto.CrossIdDTO;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.opt.dto.CrossIdAndMinutesDTO;
import net.wanji.opt.service.EvaluateService;
import net.wanji.opt.vo.EvaluateCrossDetailVO;
import net.wanji.opt.vo.EvaluateMetricsVO;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.ws.rs.core.MediaType;

/**
 * 信号评价
 *
 * @author Kent HAN
 */
@Api(value = "EvaluateController", description = "信号评价")
@RequestMapping("/evaluate")
@RestController
public class EvaluateController {

    private final EvaluateService evaluateService;

    public EvaluateController(EvaluateService evaluateService) {
        this.evaluateService = evaluateService;
    }

    @ApiOperation(value = "路口详情", notes = "路口详情", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/evaluateCrossDetail",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = EvaluateCrossDetailVO.class),
    })
    public JsonViewObject evaluateCrossDetail(@RequestBody CrossIdDTO crossIdDTO) {
        EvaluateCrossDetailVO evaluateCrossDetailVO = evaluateService.evaluateCrossDetail(crossIdDTO);
        return JsonViewObject.newInstance().success(evaluateCrossDetailVO);
    }

    @ApiOperation(value = "评价指标", notes = "评价指标", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/evaluateMetrics",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = EvaluateMetricsVO.class),
    })
    public JsonViewObject evaluateMetrics(@RequestBody CrossIdAndMinutesDTO crossIdAndMinutesDTO) {
        EvaluateMetricsVO evaluateMetricsVO = evaluateService.evaluateMetrics(crossIdAndMinutesDTO);
        return JsonViewObject.newInstance().success(evaluateMetricsVO);
    }

}