package net.wanji.opt.vo;

import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.Date;
import java.util.List;

/**
 * @author Kent HAN
 * @date 2023/2/9 8:38
 */
@Data
@NoArgsConstructor
@ApiModel(value = "OptEffectVO", description = "查询优化效果返回值")
public class OptEffectVO {
    @ApiModelProperty(value = "路口名称")
    String crossName;
    @ApiModelProperty(value = "场景")
    String sceneName;
    @ApiModelProperty(value = "应用策略")
    String strategyName;
    @ApiModelProperty(value = "优化方法")
    String ideaName;
    @ApiModelProperty(value = "优化开始时间 格式2023-03-02 10:10")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm", timezone = "GMT+8")
    Date optStartTime;
    @ApiModelProperty(value = "状态 1已完成 2持续优化")
    Integer status;
    @ApiModelProperty(value = "拥堵指数延误折线图")
    List<IndexDelay> indexDelayList;
    @ApiModelProperty(value = "最大排队长度平均停车次数折线图")
    List<QueueStop> queueStopList;

    @Data
    @NoArgsConstructor
    @ApiModel(value = "IndexDelay", description = "拥堵指数延误折线图元素")
    public static class IndexDelay {
        @ApiModelProperty(value = "时间 格式14:00")
        @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "HH:mm", timezone = "GMT+8")
        Date time;
        @ApiModelProperty(value = "拥堵指数")
        Double index;
        @ApiModelProperty(value = "延误")
        Integer delay;
    }

    @Data
    @NoArgsConstructor
    @ApiModel(value = "QueueStop", description = "最大排队长度平均停车次数折线图元素")
    public static class QueueStop {
        @ApiModelProperty(value = "时间 格式14:00")
        @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "HH:mm", timezone = "GMT+8")
        Date time;
        @ApiModelProperty(value = "最大排队长度")
        Double queue;
        @ApiModelProperty(value = "平均停车次数")
        Double stop;
    }
}
